<?php
/**
 * @file
 * Contains Drupal\reference_table_formatter\ReferenceTableFormatterPluginInterface;
 */

namespace Drupal\reference_table_formatter;

use Drupal\Core\Field\FieldConfigInterface;
use Drupal\Core\Field\FieldItemInterface;

/**
 * Interface required to implement a reference field formatter.
 */
interface FormatterInterface {
  /**
   * The the entity ID from the field value.
   *
   * @param $item
   *   The reference field to gain the ID for.
   *
   * @return int
   *   An entity ID.
   */
  function getEntityIdFromFieldItem(FieldItemInterface $item);

  /**
   * Get the target bundle from a reference field.
   *
   * @param FieldConfigInterface $field_definition
   *   The field definition to check the target bundle.
   *
   * @return string
   *   The bundle that is the target of the field.
   *
   * @throws \Exception
   */
  function getTargetBundleId(FieldConfigInterface $field_definition);

  /**
   * Get the entity which is the target of the reference field.
   *
   * @param FieldConfigInterface $field_definition
   *   The field definition.
   *
   * @return string
   *   The entity which is the target of the reference.
   */
  function getTargetEntityId(FieldConfigInterface $field_definition);

  /**
   * Get the view modes which can be selected for this field formatter.
   */
  function getConfigurableViewModes();
}
