<?php

/**
 * @file
 * Contains \Drupal\dynamic_entity_reference\Plugin\Field\FieldFormatter\DynamicEntityReferenceEntityFormatter.
 */

namespace Drupal\reference_table_formatter\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldConfigInterface;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\reference_table_formatter\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\dynamic_entity_reference\Plugin\Field\FieldFormatter\DynamicEntityReferenceFormatterTrait;

/**
 * Plugin implementation of the 'rendered entity' formatter.
 *
 * @FieldFormatter(
 *   id = "dynamic_entity_reference_table",
 *   label = @Translation("Table of Fields"),
 *   field_types = {
 *     "dynamic_entity_reference"
 *   }
 * )
 */
class DynamicEntityReference extends FormatterBase {

  use DynamicEntityReferenceFormatterTrait;

  public function viewElements(FieldItemListInterface $items, $langcode) {

    $field_storage_settings = $items->getFieldDefinition()->getFieldStorageDefinition()->getSettings();
    $entity_types = $field_storage_settings['entity_type_ids'];

    $output = [];
    foreach ($entity_types as $entity_type) {

      $filtered_items = clone $items;
      $filtered_items->filter(function($item) use ($entity_type) {
        return $item->get('target_type')->getValue() == $entity_type;
      });

      if ($entities = $this->getEntitiesToView($filtered_items, $langcode)) {
        $bundle = $entities[0]->bundle();
        $output[] = $this->referenceRenderer->getTable($entity_type, $bundle, $entities, $this->getSettings());
      }
    }

    return $output;
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityIdFromFieldItem(FieldItemInterface $item) {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getTargetBundleId(FieldConfigInterface $field_definition) {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getTargetEntityId(FieldConfigInterface $field_definition) {
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getConfigurableViewModes() {
    return [
      'default' => 'Default',
    ];
  }

}
